pub enum ValidationError {
    Schema {
        code: &'static str,
        message: Option<String>,
        location: String,
    },
    Field {
        field: Option<&'static str>,
        code: &'static str,
        params: Box<HashMap<&'static str, Value>>,
        message: Option<String>,
        location: String,
    },
}

Variants



Schema

Fields

code: &'static str

The ‘code’ usually indicating what type of validation failed

message: Option<String>

An optional message for the error

location: String

Where in the struct the validation failed. Similar to JSON pointers. Always ‘/’ for schema.



Field

Fields

field: Option<&'static str>

The name of the field

code: &'static str

The ‘code’ usually indicating what type of validation failed

params: Box<HashMap<&'static str, Value>>

The parameters used to specify the exact cause of validation failure. Will usually be actual and target.

message: Option<String>

An optional message for the error

location: String

Where in the struct the validation failed. Similar to JSON pointers.

Implementations

source

impl ValidationError

source

pub fn new_field(code: &'static str) -> ValidationError

Creates a new field validation error. This should be used when returning errors from reusable custom functions as validify will automatically set field names.

source

pub fn new_field_named( field: &'static str, code: &'static str ) -> ValidationError

Creates a new field error with the given field name and code.

source

pub fn new_schema(code: &'static str) -> ValidationError

Creates a new schema error with the given code

source

pub fn set_field(&mut self, field: &'static str)

Set the field name to the given one if the error is a field error

source

pub fn field_name(&self) -> Option<&str>

Get the error’s field name if it was a field error

source

pub fn add_param<T: Serialize>(&mut self, name: &'static str, val: &T)

source

pub fn with_param<T: Serialize>(self, name: &'static str, val: &T) -> Self

source

pub fn with_message(self, msg: String) -> Self

source

pub fn set_location<T>(&mut self, parent: T)
where T: Display,

Insert the provided parent to the 0th position of the current location

source

pub fn set_location_idx<T: Display>(&mut self, idx: T, parent: &str)

Used when the struct failing validation is nested in collections. It will concat the index to the parent so as to follow the location.

source

pub fn location(&self) -> &str

Returns the apsolute location of the error in a similiar manner to JSON pointers.

source

pub fn params(&self) -> HashMap<&'static str, Value>

source

pub fn code(&self) -> String

source

pub fn message(&self) -> Option<String>

source

pub fn set_message(&mut self, msg: String)