Validate

Trait Validate 

pub trait Validate {
    // Required method
    fn validate(&self) -> Result<(), ValidationErrors>;
}
Validates the struct/enum based on the provided #[validate] attributes. Deriving Validate allows you to specify schema and field validation on structs using the #[validate] attribute. See the repository for a full list of possible validations.

Required Methods

fn validate(&self) -> Result<(), ValidationErrors>

Apply the provided validations to self

Implementors